summaryrefslogtreecommitdiffstats
path: root/akregator/src/folder.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/folder.h')
-rw-r--r--akregator/src/folder.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/akregator/src/folder.h b/akregator/src/folder.h
index bb5529bc..32811f67 100644
--- a/akregator/src/folder.h
+++ b/akregator/src/folder.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef AKREGATOR_FOLDER_H
@@ -44,6 +44,7 @@ namespace Akregator
class Folder : public TreeNode
{
Q_OBJECT
+ TQ_OBJECT
public:
/** creates a feed group parsed from a XML dom element.
Child nodes are not inserted or parsed.
@@ -54,41 +55,41 @@ namespace Akregator
/** Creates a new folder with a given title
@param title The title of the feed group
*/
- Folder(const TQString& title = TQString::null);
+ Folder(const TQString& title = TQString());
virtual ~Folder();
virtual bool accept(TreeNodeVisitor* visitor);
- /** returns recursively concatenated articles of children
- @return an article sequence containing articles of children */
- virtual TQValueList<Article> articles(const TQString& tag=TQString::null);
+ /** returns recursively concatenated articles of tqchildren
+ @return an article sequence containing articles of tqchildren */
+ virtual TQValueList<Article> articles(const TQString& tag=TQString());
/** returns a list of all tags occurring in the subtree of this folder */
virtual TQStringList tags() const;
/** returns the number of unread articles in all children
@return number of unread articles */
virtual int unread() const;
/** returns the number of articles in all children
@return number of articles */
virtual int totalCount() const;
/** Helps the rest of the app to decide if node should be handled as group or not. Use only where necessary, use polymorphism where possible. */
virtual bool isGroup() const { return true; }
/** converts the feed group into OPML format for save and export and appends it to node @c parent in document @document.
Children are processed and appended recursively.
- @param parent The parent element
+ @param tqparent The tqparent element
@param document The DOM document
@return The newly created element representing this feed group */
- virtual TQDomElement toOPML( TQDomElement parent, TQDomDocument document ) const;
+ virtual TQDomElement toOPML( TQDomElement tqparent, TQDomDocument document ) const;
- /** returns the (direct) children of this node.
+ /** returns the (direct) tqchildren of this node.
@return a list of pointers to the child nodes
*/
- virtual TQValueList<TreeNode*> children() const;
+ virtual TQValueList<TreeNode*> tqchildren() const;
/** inserts @c node as child after child node @c after.
if @c after is not a child of this group, @c node will be inserted as first child
@@ -104,7 +105,7 @@ namespace Akregator
@param node the tree node to insert */
virtual void appendChild(TreeNode* node);
/** remove @c node from children. Note that @c node will not be deleted
@param node the child node to remove */
virtual void removeChild(TreeNode* node);
@@ -133,7 +134,7 @@ namespace Akregator
/** Delete expired articles recursively. */
virtual void slotDeleteExpiredArticles();
/** Mark articles of children recursively as read. */
virtual void slotMarkAllArticlesAsRead();
/** Called when a child was modified.
@@ -146,7 +147,7 @@ namespace Akregator
*/
virtual void slotChildDestroyed(TreeNode* node);
/** enqueues children recursively for fetching
@param queue a fetch queue
@param internvalFetchesOnly */
virtual void slotAddToFetchQueue(FetchQueue* queue, bool intervalFetchesOnly=false);
@@ -54,41 +55,41 @@ namespace Akregator
/** returns a list of all tags occurring in the subtree of this folder */
virtual TQStringList tags() const;
- /** returns the number of unread articles in all children
+ /** returns the number of unread articles in all tqchildren
virtual int unread() const;
@@ -54,41 +55,41 @@ namespace Akregator
virtual int unread() const;
- /** returns the number of articles in all children
+ /** returns the number of articles in all tqchildren
virtual int totalCount() const;
@@ -54,41 +55,41 @@ namespace Akregator
/** Helps the rest of the app to decide if node should be handled as group or not. Use only where necessary, use polymorphism where possible. */
virtual bool isGroup() const { return true; }
- /** converts the feed group into OPML format for save and export and appends it to node @c parent in document @document.
+ /** converts the feed group into OPML format for save and export and appends it to node @c tqparent in document @document.
Children are processed and appended recursively.
@@ -104,7 +105,7 @@ namespace Akregator
virtual void appendChild(TreeNode* node);
- /** remove @c node from children. Note that @c node will not be deleted
+ /** remove @c node from tqchildren. Note that @c node will not be deleted
virtual void removeChild(TreeNode* node);
@@ -133,7 +134,7 @@ namespace Akregator
/** Delete expired articles recursively. */
virtual void slotDeleteExpiredArticles();
- /** Mark articles of children recursively as read. */
+ /** Mark articles of tqchildren recursively as read. */
virtual void slotMarkAllArticlesAsRead();
/** Called when a child was modified.
@@ -146,7 +147,7 @@ namespace Akregator
*/
virtual void slotChildDestroyed(TreeNode* node);
- /** enqueues children recursively for fetching
+ /** enqueues tqchildren recursively for fetching